==> qtjambi-network-debuginfo-windows-x64-6.7.0.jar: sources/QtJambiNetwork/QRestReply_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtNetwork/qrestreply.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qjsondocument.h>
#include <QtNetwork/qnetworkreply.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QRestReply(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QRestReply")
    QRestReply *_ptr = reinterpret_cast<QRestReply *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QRestReply(QNetworkReply*)
void __qt_construct_QRestReply_QNetworkReply_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QRestReply(QNetworkReply*)")
    jobject reply0 = __java_arguments[0].l;
    QNetworkReply* __qt_reply0 = qtjambi_cast<QNetworkReply* >(__jni_env, reply0);
    QRestReply *__qt_this = new(__qtjambi_ptr) QRestReply(__qt_reply0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QRestReply::QRestReply(QNetworkReply*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_initialize_1native__Lio_qt_network_QRestReply_2Lio_qt_network_QNetworkReply_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject reply0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRestReply::QRestReply(QNetworkReply*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = reply0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRestReply_QNetworkReply_ptr, sizeof(QRestReply), typeid(QRestReply), false, &deleter_QRestReply, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QRestReply
void __qt_destruct_QRestReply(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QRestReply")
    reinterpret_cast<QRestReply*>(ptr)->~QRestReply();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QRestReply::error()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_error_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::error()const", __qt_this)
        QNetworkReply::NetworkError __qt_return_value = __qt_this->error();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::errorString()const", __qt_this)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::hasError()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_hasError_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::hasError()const", __qt_this)
        __java_return_value = __qt_this->hasError();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::httpStatus()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_httpStatus_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::httpStatus()const", __qt_this)
        __java_return_value = __qt_this->httpStatus();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::isHttpStatusSuccess()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_isHttpStatusSuccess_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::isHttpStatusSuccess()const", __qt_this)
        __java_return_value = __qt_this->isHttpStatusSuccess();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::isSuccess()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_isSuccess_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::isSuccess()const", __qt_this)
        __java_return_value = __qt_this->isSuccess();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::networkReply()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_networkReply_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::networkReply()const", __qt_this)
        QNetworkReply* __qt_return_value = __qt_this->networkReply();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::readBody()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_readBody_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::readBody()", __qt_this)
        QByteArray __qt_return_value = __qt_this->readBody();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::readJson(QJsonParseError*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_readJson_1native_1QJsonParseError_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID error0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::readJson(QJsonParseError*)", __qt_this)
        QJsonParseError* __qt_error0 = QtJambiAPI::objectFromNativeId<QJsonParseError>(error0);
        std::optional<QJsonDocument> __qt_return_value = __qt_this->readJson(__qt_error0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::readText()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_readText_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::readText()", __qt_this)
        QString __qt_return_value = __qt_this->readText();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::swap(QRestReply&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_swap_1native_1ref_1QRestReply__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::swap(QRestReply&)", __qt_this)
        QRestReply& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QRestReply>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << *__qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QRestReply(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QRestReply>("QRestReply", "io/qt/network/QRestReply");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QRestReply, {
        ConstructorInfo(&__qt_construct_QRestReply_QNetworkReply_ptr, "Lio/qt/network/QNetworkReply;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QRestReply);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-network-debuginfo-windows-x64-6.7.2.jar: sources/QtJambiNetwork/QRestReply_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtNetwork/qrestreply.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qjsondocument.h>
#include <QtNetwork/qnetworkreply.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QRestReply(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QRestReply")
    QRestReply *_ptr = reinterpret_cast<QRestReply *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QRestReply(QNetworkReply*)
void __qt_construct_QRestReply_QNetworkReply_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QRestReply(QNetworkReply*)")
    jobject reply0 = __java_arguments[0].l;
    QNetworkReply* __qt_reply0 = qtjambi_cast<QNetworkReply*>(__jni_env, reply0);
    QRestReply *__qt_this = new(__qtjambi_ptr) QRestReply(__qt_reply0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QRestReply::QRestReply(QNetworkReply*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_initialize_1native__Lio_qt_network_QRestReply_2Lio_qt_network_QNetworkReply_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject reply0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRestReply::QRestReply(QNetworkReply*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = reply0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRestReply_QNetworkReply_ptr, sizeof(QRestReply), typeid(QRestReply), 0, false, &deleter_QRestReply, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QRestReply
void __qt_destruct_QRestReply(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QRestReply")
    reinterpret_cast<QRestReply*>(ptr)->~QRestReply();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QRestReply::error()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_error_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::error()const", __this_nativeId)
        QNetworkReply::NetworkError __qt_return_value = __qt_this->error();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::errorString()const", __this_nativeId)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::hasError()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_hasError_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::hasError()const", __this_nativeId)
        __java_return_value = __qt_this->hasError();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::httpStatus()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_httpStatus_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::httpStatus()const", __this_nativeId)
        __java_return_value = __qt_this->httpStatus();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::isHttpStatusSuccess()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_isHttpStatusSuccess_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::isHttpStatusSuccess()const", __this_nativeId)
        __java_return_value = __qt_this->isHttpStatusSuccess();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::isSuccess()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_isSuccess_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::isSuccess()const", __this_nativeId)
        __java_return_value = __qt_this->isSuccess();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::networkReply()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_networkReply_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::networkReply()const", __this_nativeId)
        QNetworkReply* __qt_return_value = __qt_this->networkReply();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::readBody()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_readBody_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::readBody()", __this_nativeId)
        QByteArray __qt_return_value = __qt_this->readBody();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::readJson(QJsonParseError*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_readJson_1native_1QJsonParseError_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID error0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::readJson(QJsonParseError*)", __this_nativeId)
        QJsonParseError* __qt_error0 = QtJambiAPI::objectFromNativeId<QJsonParseError>(error0);
        std::optional<QJsonDocument> __qt_return_value = __qt_this->readJson(__qt_error0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::readText()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_readText_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::readText()", __this_nativeId)
        QString __qt_return_value = __qt_this->readText();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRestReply::swap(QRestReply&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_swap_1native_1ref_1QRestReply__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRestReply::swap(QRestReply&)", __this_nativeId)
        QRestReply& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QRestReply>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QRestReply_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QRestReply *__qt_this = QtJambiAPI::objectFromNativeId<QRestReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << *__qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QRestReply(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QRestReply>("QRestReply", "io/qt/network/QRestReply");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QRestReply, {
        ConstructorInfo(&__qt_construct_QRestReply_QNetworkReply_ptr, "Lio/qt/network/QNetworkReply;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QRestReply);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
